﻿using Demo.Domain.UseCase;
using System;

namespace Demo.UI
{
    public class UserConsole
    {
        private readonly UserUseCase _userUseCase;

        public UserConsole(UserUseCase userUseCase)
        {
            _userUseCase = userUseCase;
        }

        public void ShowAllUsers()
        {
            var users = _userUseCase.GetAllUsers();
            if (users.Count == 0)
            {
                Console.WriteLine("Пользователи не найдены.");
                return;
            }

            foreach (var user in users)
            {
                Console.WriteLine($"GUID пользователя: {user.Guid}, ФИО: {user.FIO}, ID группы: {user.GroupID}");
            }
        }

        public void UpdateUser(Guid userGuid)
        {
            Console.WriteLine("Введите новое ФИО:");
            string newFIO = Console.ReadLine();
            Console.WriteLine("Введите новый ID группы:");
            int newGroupID = int.Parse(Console.ReadLine());

            _userUseCase.UpdateUser(userGuid, newFIO, newGroupID);
            Console.WriteLine("Пользователь успешно обновлён.");
        }

        public void DeleteUser(Guid userGuid)
        {
            _userUseCase.DeleteUserByGuid(userGuid);
            Console.WriteLine("Пользователь успешно удалён.");
        }

        public void FindUser(Guid userGuid)
        {
            var user = _userUseCase.FindUserByGuid(userGuid);
            if (user != null)
            {
                Console.WriteLine($"Найден пользователь: ФИО: {user.FIO}, ID группы: {user.GroupID}");
            }
            else
            {
                Console.WriteLine("Пользователь не найден.");
            }
        }
    }
}
